@@ -51,6 +51,7 @@
 #define CFG_MOUNT_POINT "mountPoint"
 #define CFG_BACKEND "backend"
 #define CFG_ACTIVITIES "activities"
+#define CFG_OFFLINEONLY "offlineOnly"
 
 namespace PlasmaVault {
 
@@ -68,10 +69,13 @@ public:
     struct Data {
         QString name;
         MountPoint mountPoint;
+
         VaultInfo::Status status;
-        QStringList activities;
         QString message;
 
+        QStringList activities;
+        bool isOfflineOnly;
+
         QString backendName;
         Backend::Ptr backend;
     };
@@ -94,46 +98,61 @@ public:
         if (data) {
             // Checking the status, and whether we should update it
             const auto oldStatus = data->status;
-            const auto newStatus =
-                           isOpened()      ? VaultInfo::Opened :
-                           isInitialized() ? VaultInfo::Closed :
-                                             VaultInfo::NotInitialized;
 
-            if (oldStatus == newStatus) return;
+            if (oldStatus == VaultInfo::Dismantling) {
+                // This means that the vault should be forgotten
+                KConfigGroup generalConfig(config, "EncryptedDevices");
+                generalConfig.deleteEntry(device.data());
 
-            data->status = newStatus;
+                KConfigGroup vaultConfig(config, device.data());
+                vaultConfig.deleteGroup();
 
-            emit q->statusChanged(data->status);
+                emit q->statusChanged(data->status = VaultInfo::Dismantled);
 
-            if (newStatus == VaultInfo::Closed || newStatus == VaultInfo::Opened) {
-                emit q->isOpenedChanged(newStatus == VaultInfo::Opened);
+            } else {
+                const auto newStatus =
+                               isOpened()      ? VaultInfo::Opened :
+                               isInitialized() ? VaultInfo::Closed :
+                                                 VaultInfo::NotInitialized;
+
+                if (oldStatus == newStatus) return;
+
+                data->status = newStatus;
+
+                emit q->statusChanged(data->status);
+
+                if (newStatus == VaultInfo::Closed || newStatus == VaultInfo::Opened) {
+                    emit q->isOpenedChanged(newStatus == VaultInfo::Opened);
+                }
+
+                if (oldStatus == VaultInfo::NotInitialized || newStatus == VaultInfo::NotInitialized) {
+                    emit q->isInitializedChanged(newStatus);
+                }
+
+                if (oldStatus == VaultInfo::Creating
+                        || oldStatus == VaultInfo::Opening
+                        || oldStatus == VaultInfo::Closing
+                        || oldStatus == VaultInfo::Dismantling) {
+                    emit q->isBusyChanged(false);
+                }
+
+                // Saving the data for the current mount
+                KConfigGroup generalConfig(config, "EncryptedDevices");
+                generalConfig.writeEntry(device.data(), true);
+
+                KConfigGroup vaultConfig(config, device.data());
+                vaultConfig.writeEntry(CFG_LAST_STATUS, (int)data->status);
+                vaultConfig.writeEntry(CFG_MOUNT_POINT, data->mountPoint.data());
+                vaultConfig.writeEntry(CFG_NAME,        data->name);
+                vaultConfig.writeEntry(CFG_BACKEND,     data->backend->name());
+
+                vaultConfig.writeEntry(CFG_ACTIVITIES,  data->activities);
+                vaultConfig.writeEntry(CFG_OFFLINEONLY, data->isOfflineOnly);
+
+                org::kde::KDirNotify::emitFilesAdded(
+                        QUrl::fromLocalFile(data->mountPoint.data()));
             }
 
-            if (oldStatus == VaultInfo::NotInitialized || newStatus == VaultInfo::NotInitialized) {
-                emit q->isInitializedChanged(newStatus);
-            }
-
-            if (oldStatus == VaultInfo::Creating
-                    || oldStatus == VaultInfo::Opening
-                    || oldStatus == VaultInfo::Closing
-                    || oldStatus == VaultInfo::Destroying) {
-                emit q->isBusyChanged(false);
-            }
-
-            // Saving the data for the current mount
-            KConfigGroup generalConfig(config, "EncryptedDevices");
-            generalConfig.writeEntry(device.data(), true);
-
-            KConfigGroup vaultConfig(config, device.data());
-            vaultConfig.writeEntry(CFG_LAST_STATUS, (int)data->status);
-            vaultConfig.writeEntry(CFG_MOUNT_POINT, data->mountPoint.data());
-            vaultConfig.writeEntry(CFG_NAME,        data->name);
-            vaultConfig.writeEntry(CFG_BACKEND,     data->backend->name());
-            vaultConfig.writeEntry(CFG_ACTIVITIES,  data->activities);
-
-            org::kde::KDirNotify::emitFilesAdded(
-                    QUrl::fromLocalFile(data->mountPoint.data()));
-
         } else {
             emit q->isOpenedChanged(false);
             emit q->isInitializedChanged(false);
@@ -151,6 +170,7 @@ public:
             // vaultConfig.deleteEntry(CFG_NAME);
             // vaultConfig.deleteEntry(CFG_BACKEND);
             // vaultConfig.deleteEntry(CFG_ACTIVITIES);
+            // vaultConfig.deleteEntry(CFG_OFFLINEONLY);
 
             emit q->statusChanged(VaultInfo::Error);
         }
@@ -180,6 +200,7 @@ public:
         Data vaultData;
         const QString backendName    = payload[KEY_BACKEND].toString();
         const QStringList activities = payload[KEY_ACTIVITIES].toStringList();
+        const bool isOfflineOnly     = payload[KEY_OFFLINEONLY].toBool();
 
         // status should never be in this state, if we got an error,
         // d->data should not be valid
@@ -187,10 +208,11 @@ public:
 
         // Reading the mount data from the config
         const KConfigGroup vaultConfig(config, device.data());
-        vaultData.name        = vaultConfig.readEntry(CFG_NAME, name);
-        vaultData.mountPoint  = MountPoint(vaultConfig.readEntry(CFG_MOUNT_POINT, mountPoint.data()));
-        vaultData.backendName = vaultConfig.readEntry(CFG_BACKEND, backendName);
-        vaultData.activities  = vaultConfig.readEntry(CFG_ACTIVITIES, activities);
+        vaultData.name          = vaultConfig.readEntry(CFG_NAME, name);
+        vaultData.mountPoint    = MountPoint(vaultConfig.readEntry(CFG_MOUNT_POINT, mountPoint.data()));
+        vaultData.backendName   = vaultConfig.readEntry(CFG_BACKEND, backendName);
+        vaultData.activities    = vaultConfig.readEntry(CFG_ACTIVITIES, activities);
+        vaultData.isOfflineOnly = vaultConfig.readEntry(CFG_OFFLINEONLY, isOfflineOnly);
 
         const QDir mountPointDir(vaultData.mountPoint);
 
@@ -209,12 +231,12 @@ public:
             // Lets try to create the mount point
             !mountPointDir.exists() && !QDir().mkpath(vaultData.mountPoint) ?
                 errorData(Error::MountPointError,
-                          i18n("Can not create the mount point")) :
+                          i18n("Cannot create the mount point")) :
 
             // Instantiate the backend if possible
             !(vaultData.backend = Backend::instance(vaultData.backendName)) ?
                 errorData(Error::BackendError,
-                          i18n("Configured backend can not be instantiated: %1", vaultData.backendName)) :
+                          i18n("Configured backend cannot be instantiated: %1", vaultData.backendName)) :
 
             // otherwise
             ExpectedData::success(vaultData);
@@ -273,12 +295,15 @@ Vault::Vault(const Device &device, QObject *parent)
             this, [&] {
                 qDebug() << "Saving vault info:"
                          << d->data->name
+                         << d->data->mountPoint
                          << d->data->activities
-                         << d->data->mountPoint;
+                         << d->data->isOfflineOnly
+                         ;
                 KConfigGroup vaultConfig(d->config, d->device.data());
                 vaultConfig.writeEntry(CFG_MOUNT_POINT, d->data->mountPoint.data());
                 vaultConfig.writeEntry(CFG_NAME,        d->data->name);
                 vaultConfig.writeEntry(CFG_ACTIVITIES,  d->data->activities);
+                vaultConfig.writeEntry(CFG_OFFLINEONLY, d->data->isOfflineOnly);
 
                 d->config->sync();
 
@@ -290,7 +315,9 @@ Vault::Vault(const Device &device, QObject *parent)
 
 Vault::~Vault()
 {
-    close();
+    if (d->isOpened()) {
+        close();
+    }
 }
 
 
@@ -312,7 +339,7 @@ FutureResult<> Vault::create(const QString &name, const MountPoint &mountPoint,
         // we do not want to do it again
         d->data && d->data->backend->isInitialized(d->device) ?
             errorResult(Error::DeviceError,
-                        i18n("This device is already registered. Can not recreate it.")) :
+                        i18n("This device is already registered. Cannot recreate it.")) :
 
         // Mount not open, check the error messages
         !(d->data = d->loadVault(d->device, name, mountPoint, payload)) ?
@@ -341,7 +368,7 @@ FutureResult<> Vault::open(const Payload &payload)
         // We can not mount something that has not been registered
         // with us before
         !d->data ? errorResult(Error::BackendError,
-                               i18n("Can not open an unknown vault.")) :
+                               i18n("Cannot open an unknown vault.")) :
 
         // otherwise
         d->followFuture(VaultInfo::Opening,
@@ -358,7 +385,7 @@ FutureResult<> Vault::close()
         // We can not mount something that has not been registered
         // with us before
         !d->data ? errorResult(Error::BackendError,
-                               i18n("The vault is unknown, can not close it.")) :
+                               i18n("The vault is unknown, cannot close it.")) :
 
         // otherwise
         d->followFuture(VaultInfo::Closing,
@@ -458,17 +485,17 @@ FutureResult<> Vault::forceClose()
 
 
 
-FutureResult<> Vault::destroy(const Payload &payload)
+FutureResult<> Vault::dismantle(const Payload &payload)
 {
     return
         // We can not mount something that has not been registered
         // with us before
         !d->data ? errorResult(Error::BackendError,
-                               i18n("The vault is unknown, can not destroy it.")) :
+                               i18n("The vault is unknown, cannot dismantle it.")) :
 
         // otherwise
-        d->followFuture(VaultInfo::Destroying,
-                        d->data->backend->destroy(d->device, d->data->mountPoint, payload));
+        d->followFuture(VaultInfo::Dismantling,
+                        d->data->backend->dismantle(d->device, d->data->mountPoint, payload));
 }
 
 
@@ -577,6 +604,20 @@ void Vault::setActivities(const QStringList &activities)
 
 
 
+bool Vault::isOfflineOnly() const
+{
+    return d->data->isOfflineOnly;
+}
+
+void Vault::setIsOfflineOnly(bool isOfflineOnly)
+{
+    d->data->isOfflineOnly = isOfflineOnly;
+    emit isOfflineOnlyChanged(isOfflineOnly);
+    saveConfiguration();
+}
+
+
+
 QString Vault::name() const
 {
     return d->data->name;
@@ -608,7 +649,7 @@ bool Vault::isBusy() const
         case VaultInfo::Creating:
         case VaultInfo::Opening:
         case VaultInfo::Closing:
-        case VaultInfo::Destroying:
+        case VaultInfo::Dismantling:
             return true;
 
         default:
@@ -621,11 +662,16 @@ bool Vault::isBusy() const
 VaultInfo Vault::info() const
 {
     VaultInfo vaultInfo;
-    vaultInfo.device     = device();
-    vaultInfo.name       = name();
-    vaultInfo.status     = status();
-    vaultInfo.activities = activities();
-    vaultInfo.message    = message();
+
+    vaultInfo.device        = device();
+    vaultInfo.name          = name();
+
+    vaultInfo.status        = status();
+    vaultInfo.message       = message();
+
+    vaultInfo.activities    = activities();
+    vaultInfo.isOfflineOnly = isOfflineOnly();
+
     return vaultInfo;
 }
 
